# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`msftrepo`](#msftrepo): Installs the Microsoft package repositories.

### Defined types

* [`msftrepo::repo`](#msftreporepo): (Un-) Installs a repository along with its GPG key.

## Classes

### <a name="msftrepo"></a>`msftrepo`

This module installs public Microsoft package repositories containing packages
like Powershell and .NET Core. At the moment, this module only installs the
Microsoft production repository.

#### Examples

##### Include all known repositories with default configurations.

```puppet
include msftrepo
```

#### Parameters

The following parameters are available in the `msftrepo` class:

* [`repo_dir`](#repo_dir)
* [`repo_owner`](#repo_owner)
* [`repo_group`](#repo_group)
* [`key_dir`](#key_dir)
* [`key_prefix`](#key_prefix)
* [`repos`](#repos)

##### <a name="repo_dir"></a>`repo_dir`

Data type: `Optional[String]`

The directory where to install the repository file, ie
"/etc/yum.repos.d" for RedHat-based systems. If not present,
the module derives the path by itself.

Default value: ``undef``

##### <a name="repo_owner"></a>`repo_owner`

Data type: `Variant[String, Integer]`

The name or UID of the owning user of the repository file.
This parameter defaults to 0 (or "root").

Default value: `0`

##### <a name="repo_group"></a>`repo_group`

Data type: `Variant[String, Integer]`

The name or UID of the owning group of the repository file.
This parameter defaults to 0 (or "root").

Default value: `0`

##### <a name="key_dir"></a>`key_dir`

Data type: `String`

The directory where the key should be installed. This is only
used on RedHat-based systems and defaults to
"/etc/pki/rpm-gpg".

Default value: `'/etc/pki/rpm-gpg'`

##### <a name="key_prefix"></a>`key_prefix`

Data type: `String`

An additional prefix string that is added before the name of
the key file. This is only used on RedHat-based systems and
defaults to "RPM-GPG-KEY-".

Default value: `'RPM-GPG-KEY-'`

##### <a name="repos"></a>`repos`

Data type: `Hash[String, Hash[String, Variant[String, Integer, Boolean]]]`

The repositories that are being installed. The keys are the names
used for the individual repository files, which must be unique.
The values are a hash holding the parameters passed the defined
type "repo". This parameter is filled from Hiera.

Default value: `{}`

## Defined types

### <a name="msftreporepo"></a>`msftrepo::repo`

This is a utility type that is used by the msftrepo class. It is not intended
for direct use by end users.

#### Parameters

The following parameters are available in the `msftrepo::repo` defined type:

* [`repo_src`](#repo_src)
* [`repo_dir`](#repo_dir)
* [`repo_owner`](#repo_owner)
* [`repo_group`](#repo_group)
* [`key_id`](#key_id)
* [`key_src`](#key_src)
* [`key_dir`](#key_dir)
* [`key_prefix`](#key_prefix)
* [`ensure`](#ensure)

##### <a name="repo_src"></a>`repo_src`

Data type: `String`

The URL of the repositoy definition, ie the file to be copied
to "/etc/yum.repos.d".

##### <a name="repo_dir"></a>`repo_dir`

Data type: `String`

The directory where to install the repository file, ie
"/etc/yum.repos.d" for RedHat-based systems.

##### <a name="repo_owner"></a>`repo_owner`

Data type: `Variant[String, Integer]`

The name or UID of the owning user of the repository file.

##### <a name="repo_group"></a>`repo_group`

Data type: `Variant[String, Integer]`

The name or UID of the owning group of the repository file.

##### <a name="key_id"></a>`key_id`

Data type: `String`

The ID of the GPG key used by the repository.

##### <a name="key_src"></a>`key_src`

Data type: `String`

The URL of the GPG key to be installed.

##### <a name="key_dir"></a>`key_dir`

Data type: `String`

The directory where the key should be installed. This is only
used on RedHat-based systems.

##### <a name="key_prefix"></a>`key_prefix`

Data type: `String`

An additional prefix string that is added before the
name of the key file. This is only used on RedHat-based
systems.

##### <a name="ensure"></a>`ensure`

Data type: `String`

Determines whether the repository should be present or absent.
This defaults to "present".

Default value: `present`

